( cd opt/kde/share/doc/HTML/en/amor ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/amor ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kteatime ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kteatime ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kweather ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kweather ; ln -sf /opt/kde/share/doc/HTML/en/common common )
#%% begin initialize kdetoys-4.3.1
if [ -f /opt/kde/bin/plamo_update_kde.sh ]; then
	/bin/bash /opt/kde/bin/plamo_update_kde.sh
fi
#%% end
